Remove use of resources ZIP

This helps unblock removing the legacy "parsed" resource processing:

https://github.com/bazelbuild/bazel/blob/3385fd60072f2a0ea415087596308821d42bd552/src/main/java/com/google/devtools/build/lib/rules/android/AndroidResourceMergingActionBuilder.java#L221

This is being used for its side effects to validate AARs, but since the
"parsed" resource merging logic is otherwise unused, it would be easy for this
to diverge from everything.

PiperOrigin-RevId: 283653559
diff --git a/src/main/java/com/google/devtools/build/lib/rules/android/AarImport.java b/src/main/java/com/google/devtools/build/lib/rules/android/AarImport.java
index 8d2ff78..9a2fe78 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/android/AarImport.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/android/AarImport.java
@@ -120,12 +120,12 @@
     ResourceApk resourceApk = ResourceApk.of(validatedResources, mergedAssets, null, null);
 
     // There isn't really any use case for building an aar_import target on its own, so the files to
     // build could be empty. The resources zip and merged jars are added here as a sanity check for
     // Bazel developers so that `bazel build java/com/my_aar_import` will fail if the resource
-    // processing or jar merging steps fail.
+    // processing or JAR merging steps fail.
     NestedSet<Artifact> filesToBuild =
         NestedSetBuilder.<Artifact>stableOrder()
-            .add(resourceApk.getValidatedResources().getMergedResources())
+            .add(resourceApk.getValidatedResources().getJavaClassJar())
             .add(mergedJar)
             .build();
@@ -120,12 +120,12 @@
 
     // There isn't really any use case for building an aar_import target on its own, so the files to
-    // build could be empty. The resources zip and merged jars are added here as a sanity check for
+    // build could be empty. The R class JAR and merged JARs are added here as a sanity check for
     // Bazel developers so that `bazel build java/com/my_aar_import` will fail if the resource